$set 3 #Configmenu

$ #ConfigOptions
# Indstillinger
$ #FocusModel
# Fokus Model
$ #WindowPlacement
# Vindueplacering
$ #ImageDithering
# Billede Dithering
$ #OpaqueMove
# Uklar vinduesflytning
$ #FullMax
# Fuld maximering
$ #FocusNew
# Fokus nyt vindue
$ #FocusLast
# Fokus vindue ved skrivebords ndring
$ #DisableBindings
# Deaktiver tastebindinger med Scroll Lock
$ #ClickToFocus
# Klik for fokus
$ #SloppyFocus
# Dovent fokus
$ #AutoRaise
# Hv automatisk
$ #ClickRaise
# Klik for at hve
$ #SmartRows
# Intelligent placering (Rkker)
$ #SmartCols
# Intelligent placering (Sjler)
$ #Cascade
# Kaskade placering
$ #LeftRight
# Fra venstre mod hjre
$ #RightLeft
# Fra hjre mod venstre
$ #TopBottom
# Oppefra
$ #BottomTop
# Nedefra
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
